==> skl-graph-2023.17.tar.gz: skl-graph-2023.17/skl_graph/task/storage.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2018)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

"""
Example usage:
from json_any import JsonStringOf, ObjectFromJsonString, FullyQualifiedType
from skl_graph.task.storage import DescriptionForJSON, NewFromJsonDescription

skl_graph_type = FullyQualifiedType(skl_graph_t)
jsoned = JsonStringOf(skl_graph, descriptors={skl_graph_type: DescriptionForJSON})
un_jsoned = ObjectFromJsonString(
    jsoned, builders={skl_graph_type: NewFromJsonDescription}
)
"""
from typing import Any

from skl_graph.type.graph import skl_graph_t


def NewFromJsonDescription(description: tuple[Any, ...], /) -> skl_graph_t:
    """"""
    output = skl_graph_t()

    *slots, graph = description
    for s_idx in range(0, slots.__len__(), 2):
        setattr(output, slots[s_idx], slots[s_idx + 1])
    output.add_edges_from(graph.edges(data=True))

    return output


def DescriptionForJSON(graph: skl_graph_t, /) -> tuple[Any, ...]:
    """"""
    slots = []
    for slot in graph.__slots__:
        slots.extend((slot, getattr(graph, slot)))

    return tuple(slots) + (graph.AsNetworkX(),)

==> skl-graph-2023.20.tar.gz: skl-graph-2023.20/skl_graph/task/storage.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2018)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

"""
>>> from json_any import JsonStringOf, ObjectFromJsonString, FullyQualifiedType
>>> from skl_graph.task.storage import DescriptionForJSON, NewFromJsonDescription
>>> from documentation.wiki.example.minimal import skl_graph
>>>
>>> skl_graph_type = FullyQualifiedType(skl_graph_t)
>>> jsoned = JsonStringOf(skl_graph, descriptors={skl_graph_type: DescriptionForJSON})
>>> un_jsoned = ObjectFromJsonString(jsoned, builders={skl_graph_type: NewFromJsonDescription})
"""

from typing import Any

from skl_graph.type.graph import skl_graph_t


def NewFromJsonDescription(description: tuple[Any, ...], /) -> skl_graph_t:
    """"""
    output = skl_graph_t()

    *slots, graph = description
    for s_idx in range(0, slots.__len__(), 2):
        setattr(output, slots[s_idx], slots[s_idx + 1])
    output.add_edges_from(graph.edges(data=True))

    return output


def DescriptionForJSON(graph: skl_graph_t, /) -> tuple[Any, ...]:
    """"""
    slots = []
    for slot in graph.__slots__:
        slots.extend((slot, getattr(graph, slot)))

    return tuple(slots) + (graph.AsNetworkX(),)
